@@ -14,6 +14,9 @@
 # limitations under the License.
 #
 from .contact_center_insights import (
+    BulkAnalyzeConversationsMetadata,
+    BulkAnalyzeConversationsRequest,
+    BulkAnalyzeConversationsResponse,
     CalculateIssueModelStatsRequest,
     CalculateIssueModelStatsResponse,
     CalculateStatsRequest,
@@ -30,6 +33,7 @@ from .contact_center_insights import (
     DeleteConversationRequest,
     DeleteIssueModelMetadata,
     DeleteIssueModelRequest,
+    DeleteIssueRequest,
     DeletePhraseMatcherRequest,
     DeleteViewRequest,
     DeployIssueModelMetadata,
@@ -45,6 +49,9 @@ from .contact_center_insights import (
     GetPhraseMatcherRequest,
     GetSettingsRequest,
     GetViewRequest,
+    IngestConversationsMetadata,
+    IngestConversationsRequest,
+    IngestConversationsResponse,
     ListAnalysesRequest,
     ListAnalysesResponse,
     ListConversationsRequest,
@@ -71,6 +78,7 @@ from .resources import (
     Analysis,
     AnalysisResult,
     AnnotationBoundary,
+    AnnotatorSelector,
     AnswerFeedback,
     ArticleSuggestionData,
     CallAnnotation,
@@ -92,6 +100,7 @@ from .resources import (
     InterruptionData,
     Issue,
     IssueAssignment,
+    IssueMatchData,
     IssueModel,
     IssueModelLabelStats,
     IssueModelResult,
@@ -110,6 +119,9 @@ from .resources import (
 )
 
 __all__ = (
+    "BulkAnalyzeConversationsMetadata",
+    "BulkAnalyzeConversationsRequest",
+    "BulkAnalyzeConversationsResponse",
     "CalculateIssueModelStatsRequest",
     "CalculateIssueModelStatsResponse",
     "CalculateStatsRequest",
@@ -125,6 +137,7 @@ __all__ = (
     "DeleteConversationRequest",
     "DeleteIssueModelMetadata",
     "DeleteIssueModelRequest",
+    "DeleteIssueRequest",
     "DeletePhraseMatcherRequest",
     "DeleteViewRequest",
     "DeployIssueModelMetadata",
@@ -140,6 +153,9 @@ __all__ = (
     "GetPhraseMatcherRequest",
     "GetSettingsRequest",
     "GetViewRequest",
+    "IngestConversationsMetadata",
+    "IngestConversationsRequest",
+    "IngestConversationsResponse",
     "ListAnalysesRequest",
     "ListAnalysesResponse",
     "ListConversationsRequest",
@@ -165,6 +181,7 @@ __all__ = (
     "Analysis",
     "AnalysisResult",
     "AnnotationBoundary",
+    "AnnotatorSelector",
     "AnswerFeedback",
     "ArticleSuggestionData",
     "CallAnnotation",
@@ -186,6 +203,7 @@ __all__ = (
     "InterruptionData",
     "Issue",
     "IssueAssignment",
+    "IssueMatchData",
     "IssueModel",
     "IssueModelLabelStats",
     "IssueModelResult",
